###############################################################################
#
#	Copyright (c) 2015, Simon Kofler, IN3FQQ
#	
#	Interface fuer die QRG-Steuerung ueber GPIO Ports auf dem ORANGE PI ZERO
#
#    This file is part of setQRG.
#
#    setQRG is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
############################################################################### 

import time
import OPi.GPIO as GPIO

###############################################################################
# see documentation: https://opi-gpio.readthedocs.io
#
#   Pin Header  WiringPi/GPIO                   Pin Header  WiringPi/GPIO
#       3           12                              16          19
#       5           11                              18          18 
#       7           6                               19          15
#       8           198                             21          16
#       10          199                             22          2
#       11          1                               23          14
#       12          7                               24          13
#       13          0                               26          10
#       15          3
###############################################################################

### DATA OUT PIN NUMBER OF 26PIN HEADER (not GPIO number!)
DATA_PIN = 12

### CLK OUT PIN NUMBER OF 26PIN HEADER (not GPIO number!)
CLK_PIN = 13

### ENB_RX OUT PIN NUMMER OF 26PIN HEADER (not GPIO number!)
ENB_RX_PIN = 15

### ENB_TX OUT PIN NUMMER OF 26PIN HEADER (not GPIO number!)
ENB_TX_PIN = 16

###############################################################################

### ENB-Flag Zeitspanne in Sekunden
ENB_TIME = 0.05

### Taktzeit der seriellen Uebertragung, in Sekunden
CYCLETIME = 0.01



# Initialisiert die wiringpi-Bibliothek und setzt die verwendeten
# Pins in den Output-Mode
def setup():
	GPIO.setmode(GPIO.BOARD)  # physisches pin numbering
	GPIO.setup(DATA_PIN,GPIO.OUT)	# Output fuer DATA
	GPIO.setup(CLK_PIN,GPIO.OUT)	# Output fuer CLK
	GPIO.setup(ENB_RX_PIN,GPIO.OUT)	# Output fuer ENB_RX
	GPIO.setup(ENB_TX_PIN,GPIO.OUT)	# Output fuer ENB_TX
	GPIO.output(ENB_RX_PIN,0)
	GPIO.output(ENB_TX_PIN,0)
	GPIO.output(CLK_PIN,0)
	GPIO.output(DATA_PIN,0)

#
#	Schiebt ein Bitfeld val seriell aus dem DATA_PIN, MSB Zuerst
#
def sendout(bitfield):
	for i in bitfield:
		GPIO.output(DATA_PIN,i)
		GPIO.output(CLK_PIN,1)
		time.sleep(CYCLETIME)
		GPIO.output(CLK_PIN,0)
		time.sleep(CYCLETIME)
	GPIO.output(DATA_PIN,0) # Am Ende der Uebertragung wird das Bit auf LOW gesetzt

def enableRX():
	GPIO.output(ENB_RX_PIN,1)
	time.sleep(ENB_TIME)	# Halte den HIGH-Pegel am ENB_RX-Pin fuer ENB_TIME Sekunden, kann jedoch aufgrund des Schedulings des Betriebssystems etwas variieren
	GPIO.output(ENB_RX_PIN,0)


def enableTX():
	GPIO.output(ENB_TX_PIN,1)
	time.sleep(ENB_TIME)	# Halte den HIGH-Pegel am ENB_TX-Pin fuer ENB_TIME Sekunden, kann jedoch aufgrund des Schedulings des Betriebssystems etwas variieren
	GPIO.output(ENB_TX_PIN,0)

def cleanup():
	GPIO.cleanup()

